@@ -7,13 +7,18 @@ namespace eval AIT {
 
         # Instantiates and connects required common IPs
         proc init_bd {} {
-            if {${::AIT::memory_bonding}} {
-                bond_QDMA_channels
-            }
-
             # If interconnect priorities are enabled, set PCIe master as max priority
             if {${::AIT::interconPriority}} {
-                set_property -dict [list CONFIG.ENABLE_ADVANCED_OPTIONS {1} CONFIG.XBAR_DATA_WIDTH.VALUE_SRC PROPAGATED] [get_bd_cells bridge_to_host/DDR_S_AXI_Inter]
+                set data_width 32
+                if {$::AIT::arch_device eq "alveo"} {
+                    set data_width 512
+                } elseif {$::AIT::arch_device eq "zynqmp"} {
+                    set data_width 128
+                } elseif {$::AIT::arch_device eq "zynq"} {
+                    set data_width 64
+                }
+
+                set_property -dict [list CONFIG.ENABLE_ADVANCED_OPTIONS {1} CONFIG.XBAR_DATA_WIDTH.VALUE_SRC PROPAGATED CONFIG.XBAR_DATA_WIDTH $data_width] [get_bd_cells bridge_to_host/DDR_S_AXI_Inter]
                 set_property -dict [list CONFIG.S00_ARB_PRIORITY 15] [get_bd_cells bridge_to_host/DDR_S_AXI_Inter]
             }
 
@@ -88,42 +93,6 @@ namespace eval AIT {
             connect_reset [get_bd_pins managed_reset/s_axi_aresetn] "peripheral"
         }
 
-        proc bond_QDMA_channels {} {
-            set old_num_banks [dict get ${::AIT::address_map} "mem_num_banks"]
-            set old_bank_size [dict get ${::AIT::address_map} "mem_bank_size"]
-            dict set ::AIT::address_map "mem_num_banks" [expr $old_num_banks/2]
-            dict set ::AIT::address_map "mem_bank_size" [expr $old_bank_size*2]
-
-            set_property -dict [list CONFIG.USER_SAXI_14 {true}] [get_bd_cells bridge_to_host/HBM/HBM]
-            set axi_fifo [create_bd_cell -type ip -vlnv xilinx.com:ip:axi_data_fifo:* bridge_to_host/HBM/S_AXI_QDMA/AXI_fifo]
-            set_property -dict [list CONFIG.READ_FIFO_DEPTH {32}] $axi_fifo
-            delete_bd_objs [get_bd_cells bridge_to_host/HBM/S_AXI_QDMA/HBM_data_width_converter]
-            delete_bd_objs [get_bd_intf_nets bridge_to_host/HBM/S_AXI_QDMA]
-            delete_bd_objs [get_bd_intf_nets bridge_to_host/HBM/S_AXI_QDMA/HBM_protocol_converter_M_AXI]
-            connect_bd_intf_net [get_bd_intf_pins bridge_to_host/HBM/S_AXI_QDMA/S_AXI] [get_bd_intf_pins bridge_to_host/HBM/S_AXI_QDMA/HBM_protocol_converter/S_AXI]
-            connect_bd_intf_net [get_bd_intf_pins bridge_to_host/HBM/S_AXI_QDMA/HBM_protocol_converter/M_AXI] [get_bd_intf_pins bridge_to_host/HBM/S_AXI_QDMA/AXI_fifo/S_AXI]
-            connect_bd_intf_net [get_bd_intf_pins bridge_to_host/HBM/S_AXI_QDMA/M_AXI] [get_bd_intf_pins bridge_to_host/HBM/S_AXI_QDMA/AXI_fifo/M_AXI]
-            connect_bd_intf_net [get_bd_intf_pins bridge_to_host/QDMA/M_AXI] [get_bd_intf_pins bridge_to_host/HBM/S_AXI_QDMA]
-            connect_bd_net [get_bd_pins bridge_to_host/HBM/S_AXI_QDMA/QDMA_aclk] [get_bd_pins bridge_to_host/HBM/S_AXI_QDMA/AXI_fifo/aclk]
-            connect_bd_net [get_bd_pins bridge_to_host/HBM/S_AXI_QDMA/QDMA_peripheral_aresetn] [get_bd_pins bridge_to_host/HBM/S_AXI_QDMA/AXI_fifo/aresetn]
-            delete_bd_objs [get_bd_nets bridge_to_host/HBM/S_AXI_QDMA/S_AXI_QDMA_awaddr_2] [get_bd_nets bridge_to_host/HBM/S_AXI_QDMA/S_AXI_QDMA_araddr_2] [get_bd_pins bridge_to_host/HBM/S_AXI_QDMA/S_AXI_QDMA_awaddr] [get_bd_pins bridge_to_host/HBM/S_AXI_QDMA/S_AXI_QDMA_araddr]
-            set_property name S_AXI_QDMA_0 [get_bd_cells bridge_to_host/HBM/S_AXI_QDMA]
-            copy_bd_objs bridge_to_host/HBM [get_bd_cells {bridge_to_host/HBM/S_AXI_QDMA_0}]
-            connect_bd_net [get_bd_pins bridge_to_host/HBM/S_AXI_QDMA_1/QDMA_aclk] [get_bd_pins bridge_to_host/HBM/HBM/AXI_14_ACLK] [get_bd_pins bridge_to_host/HBM/QDMA_aclk]
-            connect_bd_net [get_bd_pins bridge_to_host/HBM/S_AXI_QDMA_1/QDMA_peripheral_aresetn] [get_bd_pins bridge_to_host/HBM/HBM/AXI_14_ARESET_N] [get_bd_pins bridge_to_host/HBM/QDMA_peripheral_aresetn]
-            connect_bd_intf_net [get_bd_intf_pins bridge_to_host/HBM/S_AXI_QDMA_1/M_AXI] [get_bd_intf_pins bridge_to_host/HBM/HBM/SAXI_14]
-
-            set mem_channel_bonding [create_bd_cell -type ip -vlnv bsc:ompss:memory_channel_bonding:* bridge_to_host/HBM/QDMA_mem_channel_bonding]
-            set_property -dict [list CONFIG.AXI_ID_WIDTH {4} CONFIG.AXI_ADDR_WIDTH {64} CONFIG.AXI_MASTER_DATA_WIDTH {256} CONFIG.WIDE_BANK_BITS {28} CONFIG.NARROW_BANK_CAPACITY {268435456}] $mem_channel_bonding
-            connect_bd_intf_net [get_bd_intf_pins bridge_to_host/HBM/S_AXI_QDMA] [get_bd_intf_pins $mem_channel_bonding/s_axi]
-            connect_bd_intf_net [get_bd_intf_pins bridge_to_host/HBM/S_AXI_QDMA_0/S_AXI] [get_bd_intf_pins $mem_channel_bonding/m0_axi]
-            connect_bd_intf_net [get_bd_intf_pins bridge_to_host/HBM/S_AXI_QDMA_1/S_AXI] [get_bd_intf_pins $mem_channel_bonding/m1_axi]
-            connect_bd_net [get_bd_pins $mem_channel_bonding/clk] [get_bd_pins bridge_to_host/QDMA/aclk]
-            connect_bd_net [get_bd_pins $mem_channel_bonding/rstn] [get_bd_pins bridge_to_host/QDMA/aresetn]
-            connect_bd_net [get_bd_pins bridge_to_host/HBM/S_AXI_QDMA_awaddr] [get_bd_pins $mem_channel_bonding/s_axi_awaddr]
-            connect_bd_net [get_bd_pins bridge_to_host/HBM/S_AXI_QDMA_araddr] [get_bd_pins $mem_channel_bonding/s_axi_araddr]
-        }
-
         # Initializes axi_interfaces variable with the available AXI interfaces along with their occupation
         proc get_bd_axi_interfaces {} {
             variable axi_interfaces
@@ -159,15 +128,31 @@ namespace eval AIT {
         proc configure_address_map {} {
             AIT::info_msg "Using generic configure_address_map procedure"
 
+            set mem_type [dict get ${::AIT::address_map} "mem_type"]
+            set base_addr [dict get ${::AIT::address_map} "mem_base_addr"]
+
             # Assign memory address space
             if {(${::AIT::arch_device} eq "zynq") || (${::AIT::arch_device} eq "zynqmp")} {
+                set mem_size [dict get ${::AIT::address_map} "mem_size"]
                 assign_bd_address [get_bd_addr_segs -regexp ".*HP._DDR_LOW.*"]
-                set_property -quiet offset [dict get ${::AIT::address_map} "mem_base_addr"] [get_bd_addr_segs -regexp ".*SEG_.*HP._DDR_LOW.*"]
-                set_property -quiet range [dict get ${::AIT::address_map} "mem_size"] [get_bd_addr_segs -regexp ".*SEG_.*HP._DDR_LOW.*"]
-            } else {
-                for {set i 0} {$i < [dict get ${::AIT::address_map} "mem_num_banks"]} {incr i} {
-                    if {[llength [get_bd_addr_segs -regexp ".*DDR_${i}.*_DDR4_ADDRESS_BLOCK"]]} {
-                        assign_bd_address [get_bd_addr_segs -regexp ".*DDR_${i}.*_DDR4_ADDRESS_BLOCK"] -offset [expr [dict get ${::AIT::address_map} "mem_base_addr"] + [dict get ${::AIT::address_map} "mem_bank_size"]*$i] -range [dict get ${::AIT::address_map} "mem_bank_size"]
+                set_property -quiet offset $base_addr [get_bd_addr_segs -regexp ".*SEG_.*HP._DDR_LOW.*"]
+                set_property -quiet range $mem_size [get_bd_addr_segs -regexp ".*SEG_.*HP._DDR_LOW.*"]
+            } elseif {${::AIT::arch_device} eq "alveo"} {
+                set bank_size [dict get ${::AIT::address_map} "mem_bank_size"]
+                set num_banks [dict get ${::AIT::address_map} "mem_num_banks"]
+                if {$mem_type eq "ddr"} {
+                    for {set i 0} {$i < $num_banks} {incr i} {
+                        if {[llength [get_bd_addr_segs -regexp ".*DDR_${i}.*_DDR4_ADDRESS_BLOCK"]]} {
+                            assign_bd_address [get_bd_addr_segs -regexp ".*DDR_${i}.*_DDR4_ADDRESS_BLOCK"] -offset [expr $base_addr + $bank_size*$i] -range $bank_size
+                        }
+                    }
+                } elseif {$mem_type eq "hbm"} {
+                    for {set i 0} {$i < $num_banks} {incr i} {
+                        if {[llength [get_bd_addr_segs -regexp ".*SAXI_[format %02u $i].*HBM_MEM.*"]]} {
+                            for {set j 0} {$j < $num_banks} {incr j} {
+                                assign_bd_address [get_bd_addr_segs -regexp ".*SAXI_[format %02u $i].*HBM_MEM[format %02u $j]"] -offset [expr $base_addr + $bank_size*$j] -range $bank_size
+                            }
+                        }
                     }
                 }
             }
@@ -451,12 +436,6 @@ namespace eval AIT {
             set_property -dict [list CONFIG.NUM_${role}I [expr ($counter%16) + 1]] [get_bd_cells $inter]
             set_property -quiet -dict [list CONFIG.STRATEGY ${::AIT::interconOpt}] [get_bd_cells $inter]
 
-            if {${::AIT::interconPriority}} {
-                # Enable advanced settings in order to set priorities and set proper data path
-                set_property -dict [list CONFIG.ENABLE_ADVANCED_OPTIONS {1} CONFIG.XBAR_DATA_WIDTH.VALUE_SRC PROPAGATED] [get_bd_cells $inter]
-                # Set priority (0-15)
-                set_property -dict [list CONFIG.${port}_ARB_PRIORITY [expr 15 - ($counter%16)]] [get_bd_cells $inter]
-            }
             connect_clock [get_bd_pins $inter/${port}_ACLK]
             connect_reset [get_bd_pins $inter/${port}_ARESETN] "peripheral"
             connect_bd_intf_net -boundary_type upper [get_bd_intf_pins $src] [get_bd_intf_pins $inter/${port}_AXI]
@@ -485,6 +464,25 @@ namespace eval AIT {
 
             set interface [connect_to_interface $src data S $num]
 
+            if {${::AIT::interconPriority}} {
+                set data_width 32
+                if {$::AIT::arch_device eq "alveo"} {
+                    set data_width 512
+                } elseif {$::AIT::arch_device eq "zynqmp"} {
+                    set data_width 128
+                } elseif {$::AIT::arch_device eq "zynq"} {
+                    set data_width 64
+                }
+
+                regsub {_AXI} [lindex $interface 1] "" port
+                regsub {S} $port "" counter
+                set counter [scan $counter %d]
+                # Enable advanced settings in order to set priorities and set proper data path
+                set_property -dict [list CONFIG.ENABLE_ADVANCED_OPTIONS {1} CONFIG.XBAR_DATA_WIDTH.VALUE_SRC PROPAGATED] [get_bd_cells [lindex $interface 0]]
+                # Set priority (0-15)
+                set_property -dict [list CONFIG.${port}_ARB_PRIORITY [expr 15 - ($counter%16)] CONFIG.XBAR_DATA_WIDTH $data_width] [get_bd_cells [lindex $interface 0]]
+            }
+
             if {${::AIT::interleaving_stride} ne "None"} {
                 connect_bd_net [get_bd_pins ${src}_awaddr] [get_bd_pins [lindex $interface 0]/[lindex $interface 1]_awaddr]
                 connect_bd_net [get_bd_pins ${src}_araddr] [get_bd_pins [lindex $interface 0]/[lindex $interface 1]_araddr]
