@@ -108,7 +108,7 @@ class ArgParser():
         self.parser.add_argument('--debug_intfs', help='choose which interfaces mark for debug and instantiate the correspondent ILA cores\nAXI: debug accelerator\'s AXI interfaces\nstream: debug accelerator\'s AXI-Stream interfaces\nboth: debug both accelerator\'s AXI and AXI-Stream interfaces\ncustom: debug user-defined interfaces\nnone: do not mark for debug any interface\n(def: \'none\')', choices=['AXI', 'stream', 'both', 'custom', 'none'], metavar='INTF_TYPE', default='none')
         self.parser.add_argument('--debug_intfs_list', help='path of file with the list of interfaces to debug', type=FileType())
         self.parser.add_argument('--ignore_eng_sample', help='ignore engineering sample status from chip part number', action='store_true', default=False)
-        self.parser.add_argument('--target_language', help='choose target language to synthesize files to: VHDL or Verilog\n(def: \'VHDL\')', choices=['VHDL', 'Verilog'], metavar='TARGET_LANG', default='VHDL')
+        self.parser.add_argument('--target_language', help='choose target language to synthesize files to: vhdl or verilog\n(def: \'verilog\')', choices=['vhdl', 'verilog'], metavar='TARGET_LANG', default='verilog')
 
     def check_args(self, args):
         if args.debug_intfs == 'custom' and args.debug_intfs_list is None:
@@ -133,8 +133,8 @@ class ArgParser():
             elif math.log2(decimalFromHumanReadable(board.mem.bank_size)) - math.log2(args.memory_interleaving_stride) < math.ceil(math.log2(board.mem.num_banks)):
                 msg.error('Max allowed interleaving stride in current board: ' + decimalToHumanReadable(2**(math.log2(decimalFromHumanReadable(board.mem.bank_size)) - math.ceil(math.log2(board.mem.num_banks))), 2))
 
-        if args.enable_memory_bonding and board.mem.type != 'hbm':
-            msg.error('Memory channel bonding is only available for HBM memories')
+        if args.interconnect_priorities and (board.arch.device == 'zynq' or board.arch.device == 'zynqmp'):
+            msg.error('Memory interconnect priorities are not available on neither Zynq nor ZynqMP boards')
 
         if args.simplify_interconnection and (board.arch.device == 'zynq' or board.arch.device == 'zynqmp'):
             msg.error('Simplify memory interconnection is not available on neither Zynq nor ZynqMP boards')
