@@ -230,7 +230,6 @@ class ArgParser:
         datapath_args = self.parser.add_argument_group('Data path')
         datapath_args.add_argument('--datainterfaces_map', help='path of mappings file for the data interfaces', type=FileType())
         datapath_args.add_argument('--memory_interleaving_stride', help='size in bytes of the stride of the memory interleaving. By default there is no interleaving', metavar='MEM_INTERLEAVING_STRIDE', type=HumanReadableType(vmin='4K'))
-        datapath_args.add_argument('--enable_memory_bonding', help='bond memory channels to increase data throughput. By default there is no bonding', action='store_true', default=False)
 
         # Hardware Runtime arguments
         hwruntime_args = self.parser.add_argument_group('Hardware Runtime')
@@ -323,8 +322,8 @@ class ArgParser:
 
     def check_required_args(self, args):
         # Validate required args
-        if not re.match('^[A-Za-z][A-Za-z0-9_]*$', args.name):
-            msg.error('Invalid project name. Must start with a letter and contain only letters, numbers or underscores')
+        if re.search('(^[^A-Za-z])|(\W|__)|([^A-Za-z0-9]$)', args.name):
+            msg.error('Invalid project name. Must start with a letter, contain only letters, numbers or non-consecutive underscores, and end with a letter or number')
 
         if args.wrapper_version and args.wrapper_version < MIN_WRAPPER_VERSION:
             msg.error('Unsupported wrapper version (' + str(args.wrapper_version) + '). Minimum version is ' + str(MIN_WRAPPER_VERSION))
