@@ -1,6 +1,6 @@
 
 # Loading additional proc with user specified bodies to compute parameter values.
-source [file join [file dirname [file dirname [info script]]] gui/picosompssmanager_v6_0.gtcl]
+source [file join [file dirname [file dirname [info script]]] gui/picosompssmanager_v6_1.gtcl]
 
 # Definitional proc to organize widgets for parameters.
 proc init_gui { IPINST } {
@@ -10,6 +10,8 @@ proc init_gui { IPINST } {
   ipgui::add_param $IPINST -name "AXILITE_INTF" -parent ${Page_0}
   ipgui::add_param $IPINST -name "CMDIN_SUBQUEUE_LEN" -parent ${Page_0}
   ipgui::add_param $IPINST -name "CMDOUT_SUBQUEUE_LEN" -parent ${Page_0}
+  ipgui::add_param $IPINST -name "DBG_AVAIL_COUNT_EN" -parent ${Page_0}
+  ipgui::add_param $IPINST -name "DBG_AVAIL_COUNT_W" -parent ${Page_0}
   ipgui::add_param $IPINST -name "ENABLE_DEPS" -parent ${Page_0}
   ipgui::add_param $IPINST -name "ENABLE_SPAWN_QUEUES" -parent ${Page_0}
   ipgui::add_param $IPINST -name "ENABLE_TASK_CREATION" -parent ${Page_0}
@@ -38,6 +40,44 @@ proc init_gui { IPINST } {
 
 }
 
+proc update_PARAM_VALUE.DBG_AVAIL_COUNT_EN { PARAM_VALUE.DBG_AVAIL_COUNT_EN PARAM_VALUE.AXILITE_INTF } {
+	# Procedure called to update DBG_AVAIL_COUNT_EN when any of the dependent parameters in the arguments change
+	
+	set DBG_AVAIL_COUNT_EN ${PARAM_VALUE.DBG_AVAIL_COUNT_EN}
+	set AXILITE_INTF ${PARAM_VALUE.AXILITE_INTF}
+	set values(AXILITE_INTF) [get_property value $AXILITE_INTF]
+	if { [gen_USERPARAMETER_DBG_AVAIL_COUNT_EN_ENABLEMENT $values(AXILITE_INTF)] } {
+		set_property enabled true $DBG_AVAIL_COUNT_EN
+	} else {
+		set_property enabled false $DBG_AVAIL_COUNT_EN
+	}
+}
+
+proc validate_PARAM_VALUE.DBG_AVAIL_COUNT_EN { PARAM_VALUE.DBG_AVAIL_COUNT_EN } {
+	# Procedure called to validate DBG_AVAIL_COUNT_EN
+	return true
+}
+
+proc update_PARAM_VALUE.DBG_AVAIL_COUNT_W { PARAM_VALUE.DBG_AVAIL_COUNT_W PARAM_VALUE.AXILITE_INTF PARAM_VALUE.DBG_AVAIL_COUNT_EN } {
+	# Procedure called to update DBG_AVAIL_COUNT_W when any of the dependent parameters in the arguments change
+	
+	set DBG_AVAIL_COUNT_W ${PARAM_VALUE.DBG_AVAIL_COUNT_W}
+	set AXILITE_INTF ${PARAM_VALUE.AXILITE_INTF}
+	set DBG_AVAIL_COUNT_EN ${PARAM_VALUE.DBG_AVAIL_COUNT_EN}
+	set values(AXILITE_INTF) [get_property value $AXILITE_INTF]
+	set values(DBG_AVAIL_COUNT_EN) [get_property value $DBG_AVAIL_COUNT_EN]
+	if { [gen_USERPARAMETER_DBG_AVAIL_COUNT_W_ENABLEMENT $values(AXILITE_INTF) $values(DBG_AVAIL_COUNT_EN)] } {
+		set_property enabled true $DBG_AVAIL_COUNT_W
+	} else {
+		set_property enabled false $DBG_AVAIL_COUNT_W
+	}
+}
+
+proc validate_PARAM_VALUE.DBG_AVAIL_COUNT_W { PARAM_VALUE.DBG_AVAIL_COUNT_W } {
+	# Procedure called to validate DBG_AVAIL_COUNT_W
+	return true
+}
+
 proc update_PARAM_VALUE.DM_DS { PARAM_VALUE.DM_DS PARAM_VALUE.ENABLE_TASK_CREATION PARAM_VALUE.ENABLE_DEPS } {
 	# Procedure called to update DM_DS when any of the dependent parameters in the arguments change
 	
@@ -401,6 +441,16 @@ proc update_MODELPARAM_VALUE.ENABLE_DEPS { MODELPARAM_VALUE.ENABLE_DEPS PARAM_VA
 	set_property value [get_property value ${PARAM_VALUE.ENABLE_DEPS}] ${MODELPARAM_VALUE.ENABLE_DEPS}
 }
 
+proc update_MODELPARAM_VALUE.DBG_AVAIL_COUNT_EN { MODELPARAM_VALUE.DBG_AVAIL_COUNT_EN PARAM_VALUE.DBG_AVAIL_COUNT_EN } {
+	# Procedure called to set VHDL generic/Verilog parameter value(s) based on TCL parameter value
+	set_property value [get_property value ${PARAM_VALUE.DBG_AVAIL_COUNT_EN}] ${MODELPARAM_VALUE.DBG_AVAIL_COUNT_EN}
+}
+
+proc update_MODELPARAM_VALUE.DBG_AVAIL_COUNT_W { MODELPARAM_VALUE.DBG_AVAIL_COUNT_W PARAM_VALUE.DBG_AVAIL_COUNT_W } {
+	# Procedure called to set VHDL generic/Verilog parameter value(s) based on TCL parameter value
+	set_property value [get_property value ${PARAM_VALUE.DBG_AVAIL_COUNT_W}] ${MODELPARAM_VALUE.DBG_AVAIL_COUNT_W}
+}
+
 proc update_MODELPARAM_VALUE.MAX_ARGS_PER_TASK { MODELPARAM_VALUE.MAX_ARGS_PER_TASK PARAM_VALUE.MAX_ARGS_PER_TASK } {
 	# Procedure called to set VHDL generic/Verilog parameter value(s) based on TCL parameter value
 	set_property value [get_property value ${PARAM_VALUE.MAX_ARGS_PER_TASK}] ${MODELPARAM_VALUE.MAX_ARGS_PER_TASK}
